@@ -16,8 +16,9 @@ class AccountResource(BaseResource):
         else:
             return UnitError.from_json_api(response.json())
 
-    def close_account(self, account_id: str, reason: Optional[Literal["ByCustomer", "Fraud"]] = "ByCustomer") -> Union[UnitResponse[AccountDTO], UnitError]:
-        response = super().post(f"{self.resource}/{account_id}/close", {"attributes": { "reason": reason }})
+    def close_account(self, request: CloseAccountRequest) -> Union[UnitResponse[AccountDTO], UnitError]:
+        payload = request.to_json_api()
+        response = super().post(f"{self.resource}/{request.account_id}/close", payload)
         if super().is_20x(response.status_code):
             data = response.json().get("data")
             return UnitResponse[AccountDTO](DtoDecoder.decode(data), None)
@@ -41,7 +42,7 @@ class AccountResource(BaseResource):
         else:
             return UnitError.from_json_api(response.json())
 
-    def list(self, offset: int = 0, limit: int = 100) -> Union[UnitResponse[list[AccountDTO]], UnitError]:
+    def list(self, offset: int = 0, limit: int = 100) -> Union[UnitResponse[List[AccountDTO]], UnitError]:
         response = super().get(self.resource, {"page[limit]": limit, "page[offset]": offset})
         if super().is_20x(response.status_code):
             data = response.json().get("data")
